@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Depak;
 
-our $DATE = '2016-02-22'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.20'; # VERSION
 
 use 5.010001;
 use strict;
@@ -16,7 +16,7 @@ use File::Slurper qw(read_binary write_binary);
 use File::Temp qw(tempfile tempdir);
 use File::Which;
 use IPC::System::Options qw(system);
-use JSON;
+use JSON::MaybeXS;
 use List::Util qw(first);
 
 use Moose;
@@ -147,7 +147,7 @@ sub munge_script {
     my $stdout;
     system({die=>1, log=>1, shell=>0, capture_stdout=>\$stdout}, @depak_cmd);
 
-    my $depak_res = JSON::decode_json($stdout);
+    my $depak_res = JSON::MaybeXS::decode_json($stdout);
     $self->log_fatal(["depak failed: %s", $depak_res])
         unless $depak_res->[0] == 200;
 
@@ -255,7 +255,7 @@ Dist::Zilla::Plugin::Depak - Pack dependencies onto scripts during build using '
 
 =head1 VERSION
 
-This document describes version 0.19 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2016-02-22.
+This document describes version 0.20 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
